==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ro.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendar",
    "Todos" : "De făcut",
    "{actor} created calendar {calendar}" : "{actor} a creat calendarul {calendar}",
    "You created calendar {calendar}" : "Ai creat calendarul {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} a șters calendarul {calendar}",
    "You deleted calendar {calendar}" : "Ai șters calendarul {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} a actualiza calendarul {calendar}",
    "You updated calendar {calendar}" : "Ai actualizat calendarul {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} a partajat calendarul {calendar} cu tine",
    "You shared calendar {calendar} with {user}" : "Ai partajat calendarul {calendar} cu {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} a partajat calendarul {calendar} cu {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} a eliminat partajarea calendarului {calendar} cu tine",
    "You unshared calendar {calendar} from {user}" : "Ai eliminat partajarea calendarului {calendar} cu {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} a eliminat partajarea calendarului {calendar} cu {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} a eliminat partajarea calendarului {calendar} catre sine",
    "You shared calendar {calendar} with group {group}" : "Ai partajat calendarul {calendar} cu grupul {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} a partajat calendarul {calendar} cu grupul {group}",
    "You unshared calendar {calendar} from group {group}" : "Ai eliminat partajarea calendarului {calendar} către grupul {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} a elimina partajarea calendarului {calendar} către grupul {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} a creat evenimentul {event} în calendarul {calendar}",
    "You created event {event} in calendar {calendar}" : "Ai creat evenimentul {event} în calendarul {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} a șters evenimentul {event} din calendarul {calendar}",
    "You deleted event {event} from calendar {calendar}" : "AI șters evenimentul {event} din calendarul {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} a actualizat evenimentul {event} din calendarul {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ai actualizat evenimentul {event} din calendarul {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} a creat lista {todo} în calendarul {calendar}",
    "You created todo {todo} in list {calendar}" : "Ai creat lista {todo} în lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} a șters lista {todo} din calendarul {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Ai șters lista {todo} din calendarul {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} a actualizat lista {todo} din calendarul {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ai actualizat lista {todo} din calendarul {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} a completat lista {todo} din calendarul {calendar}",
    "You solved todo {todo} in list {calendar}" : "Ai completat lista {todo} din calendarul {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} a redeschis lista {todo} din calendarul {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Ai redeschis lista {todo} din calendarul {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendar</strong> a fost modificat",
    "A calendar <strong>event</strong> was modified" : "Un <strong>eveniment</strong> din calendar a fost modificat",
    "A calendar <strong>todo</strong> was modified" : "O <strong>listă</strong> din calendar a fost modificată",
    "Contact birthdays" : "Zile de naștere ale persoanelor de contact",
    "Personal" : "Personal",
    "Contacts" : "Persoane de contact",
    "Technical details" : "Detalii tehnice",
    "Remote Address: %s" : "Adresă la distanță: %s",
    "Request ID: %s" : "ID-ul cererii: %s"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ro.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendar",
    "Todos" : "De făcut",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} a creat calendarul {calendar}",
    "You created calendar {calendar}" : "Ai creat calendarul {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} a șters calendarul {calendar}",
    "You deleted calendar {calendar}" : "Ai șters calendarul {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} a actualiza calendarul {calendar}",
    "You updated calendar {calendar}" : "Ai actualizat calendarul {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} a partajat calendarul {calendar} cu tine",
    "You shared calendar {calendar} with {user}" : "Ai partajat calendarul {calendar} cu {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} a partajat calendarul {calendar} cu {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} a eliminat partajarea calendarului {calendar} cu tine",
    "You unshared calendar {calendar} from {user}" : "Ai eliminat partajarea calendarului {calendar} cu {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} a eliminat partajarea calendarului {calendar} cu {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} a eliminat partajarea calendarului {calendar} catre sine",
    "You shared calendar {calendar} with group {group}" : "Ai partajat calendarul {calendar} cu grupul {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} a partajat calendarul {calendar} cu grupul {group}",
    "You unshared calendar {calendar} from group {group}" : "Ai eliminat partajarea calendarului {calendar} către grupul {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} a elimina partajarea calendarului {calendar} către grupul {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} a creat evenimentul {event} în calendarul {calendar}",
    "You created event {event} in calendar {calendar}" : "Ai creat evenimentul {event} în calendarul {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} a șters evenimentul {event} din calendarul {calendar}",
    "You deleted event {event} from calendar {calendar}" : "AI șters evenimentul {event} din calendarul {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} a actualizat evenimentul {event} din calendarul {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ai actualizat evenimentul {event} din calendarul {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} a creat lista {todo} în calendarul {calendar}",
    "You created todo {todo} in list {calendar}" : "Ai creat lista {todo} în lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} a șters lista {todo} din calendarul {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Ai șters lista {todo} din calendarul {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} a actualizat lista {todo} din calendarul {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ai actualizat lista {todo} din calendarul {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} a completat lista {todo} din calendarul {calendar}",
    "You solved todo {todo} in list {calendar}" : "Ai completat lista {todo} din calendarul {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} a redeschis lista {todo} din calendarul {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Ai redeschis lista {todo} din calendarul {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendar</strong> a fost modificat",
    "A calendar <strong>event</strong> was modified" : "Un <strong>eveniment</strong> din calendar a fost modificat",
    "A calendar <strong>todo</strong> was modified" : "O <strong>listă</strong> din calendar a fost modificată",
    "Contact birthdays" : "Zile de naștere ale persoanelor de contact",
    "Where:" : "Unde:",
    "Description:" : "Descriere:",
    "_%n year_::_%n years_" : ["%nan","%nani","%nani"],
    "%1$s via %2$s" : "%1$sprin %2$s",
    "Hello %s," : "Salut %s,",
    "Accept" : "Accept",
    "Decline" : "Refuză",
    "Contacts" : "Persoane de contact",
    "WebDAV" : "WebDAV",
    "Technical details" : "Detalii tehnice",
    "Remote Address: %s" : "Adresă la distanță: %s",
    "Request ID: %s" : "ID-ul cererii: %s",
    "Tentative" : "Tentativă",
    "Save" : "Salvează"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
